@@ -1,6 +1,9 @@
 #!/usr/bin/perl
 use lib '../lib';
-use SAP::Rfc;
+use lib './lib';
+use lib '../blib';
+#use SAP::Rfc;
+use SAP::SOAP;
 use Data::Dumper;
 
 $|++;
@@ -8,14 +11,13 @@ $|++;
 #   then get the source code of each
 
 
-my $rfc = new SAP::Rfc(
-              ASHOST   => 'kogut',
+my $rfc = new SAP::SOAP(
+              ASHOST   => 'localhost',
               USER     => 'DEVELOPER',
-              PASSWD   => 'secret',
+              PASSWD   => '19920706',
               LANG     => 'EN',
               CLIENT   => '000',
-		       SYSNR    => '17');
-#              TRACE    => '1' );
+	       SYSNR    => '18');
 
 my $it = $rfc->discover("RFC_READ_TABLE");
 
@@ -25,14 +27,14 @@ $it->ROWCOUNT( 5 );
 $it->OPTIONS( ["NAME LIKE 'RS%'"] );
 
 $rfc->callrfc( $it );
-print "SOAP REQUEST AFTER: ".$it->soapResponse();
+print "SOAP REQUEST AFTER: ".$rfc->soapResponse($it);
 
 my $if = $rfc->discover("RFC_READ_REPORT");
 $if->PROGRAM('SAPLGRAP');
 $rfc->callrfc( $if );
 print "DONE CALL \n";
 
-print "SOAP REQUEST AFTER: ".$if->soapResponse();
+print "SOAP REQUEST AFTER: ".$rfc->soapResponse($if);
 
 $rfc->close();
 
